@@ -9,8 +9,11 @@ class BaseAdapter(ABC):
     _client_error_codes: dict = dict()
     _client_exception_class = None
     _server_exception_class = None
+    _client_error_messages: dict = {}
+    __client_error_codes: tuple = ()
 
     def __init__(self):
+        self._validate_client_error_messages()
         if None in (self._client_exception_class, self._server_exception_class):
             raise AdapterError('Exception classes not set.')
         super().__init__()
@@ -26,11 +29,16 @@ class BaseAdapter(ABC):
     def _get_error_code(self, error_message: str):
         if not isinstance(error_message, str):
             raise AdapterError('Only string error message accepted.')
-        for key, value in self._client_error_codes.items():
+        for key, value in self._client_error_messages.items():
             if error_message in value:
                 return key
         return 'unknown_client_error'
 
+    def _validate_client_error_messages(self):
+        for error_code in self.__client_error_codes:
+            if error_code not in self._client_error_messages.keys():
+                raise AdapterError(f'Error message not set for error code {error_code}.')
+
 
 class BaseFactory:
     __instance = None
