@@ -81,7 +81,7 @@ class BaseTasks(HttpClient):
             location: 'europe-west1'
             in_seconds: None
         """
-        super().__init__(service, path, access_token)
+        super().__init__(service=service, path=path, access_token=access_token)
         self._queue_path = self._client.queue_path(self._project, location, queue)
         self._in_seconds = in_seconds
 
