@@ -29,26 +29,6 @@ class PointError(Exception):
     pass
 
 
-class SyncOnly(PointError):
-    pass
-
-
-class LookupFieldValueNone(PointError):
-    pass
-
-
-class SortByNotSet(PointError):
-    pass
-
-
-class ContractNotSet(PointError):
-    pass
-
-
-class PaginationError(PointError):
-    pass
-
-
 class PointRequestError(PointError):
     default_url = None
     default_status_code = status.HTTP_500_INTERNAL_SERVER_ERROR
@@ -103,7 +83,7 @@ class Point:
     @log
     def __init__(self,
                  user: User,
-                 query_params: dict = None,
+                 query_params: Union[None, dict] = None,
                  is_async: bool = False,
                  timeout: tuple = (30, 30)
                  ):
@@ -127,7 +107,7 @@ class Point:
     @property
     def _query_params(self) -> dict:
         if self._is_async:
-            SyncOnly('Query params only for sync queries.')
+            PointError('Query params only for sync queries.')
         return self.__query_params
 
     @property
@@ -148,7 +128,7 @@ class Point:
 
     def _post_file(self, file, file_name, type_):
         if self._is_async:
-            raise SyncOnly('Post file allowed only for sync request.')
+            raise PointError('Post file allowed only for sync request.')
         self._response = self._client.post_file(file=file, file_name=file_name, type_=type_)
         self._handle_error(self._response)
 
@@ -173,19 +153,13 @@ class ObjectPoint(Point):
 
     def __init__(self,
                  user: User,
-                 lookup_field_value: Union[None, str, int] = None,
+                 lookup_field_value: Union[str, int],
                  is_async: bool = False,
                  timeout: tuple = (30, 30),
                  ):
-        if lookup_field_value is None:
-            raise LookupFieldValueNone('lookup_field_value not filled')
         self._lookup_field_value = lookup_field_value
         self._point_id.lookup_field_value = lookup_field_value
-        super().__init__(user=user,
-                         query_params=None,
-                         is_async=is_async,
-                         timeout=timeout,
-                         )
+        super().__init__(user=user, is_async=is_async, timeout=timeout)
 
     def _put(self, payload: dict):
         self._response = self._client.put(payload=payload)
@@ -219,7 +193,7 @@ class ContractPoint(FilterMixin, CacheMixin, Point):
 
     def _get_sorted_data(self) -> tuple:
         if self._sort_by is None:
-            raise SortByNotSet('Set key for sort or False')
+            raise PointError('Set key for sort or False')
         validated_data = self._get_validated_data()
         sorted_data = sorted(validated_data, key=lambda obj: obj[self._sort_by]) if self._sort_by else validated_data
         return tuple(sorted_data)
@@ -248,14 +222,14 @@ class ContractPoint(FilterMixin, CacheMixin, Point):
         if self._cache is not None or self._pagination_pages is None:
             page_data = get_data
             if not isinstance(page_data, list):
-                raise PaginationError('Endpoint pagination enable.')
+                raise PointError('Endpoint pagination enable.')
         else:
             if isinstance(get_data, list):
-                raise PaginationError('Endpoint pagination disable.')
+                raise PointError('Endpoint pagination disable.')
             self._next_pagination_page = get_data.get('next')
             page_data = get_data.get('results')
             if page_data is None:
-                raise PaginationError('Endpoint pagination disable.')
+                raise PointError('Endpoint pagination disable.')
         return page_data
 
     def _get_contract(self, data, is_read: bool) -> Contract:
@@ -312,7 +286,7 @@ class ListPointMixin:
 
     def list(self) -> tuple:
         if self._read_contract is None:
-            raise ContractNotSet(f'Set attr read_contract')
+            raise PointError(f'Set attr read_contract')
         return self._get_sorted_data()
 
 
@@ -321,7 +295,7 @@ class RetrievePointMixin:
 
     def retrieve(self) -> OrderedDict:
         if self._read_contract is None:
-            raise ContractNotSet(f'Set attr read_contract')
+            raise PointError(f'Set attr read_contract')
         return self._get_validated_data()
 
 
@@ -330,7 +304,7 @@ class CreatePointMixin:
 
     def create(self, payload: dict):
         if self._create_contract is None:
-            raise ContractNotSet(f'Set attr create_contract')
+            raise PointError(f'Set attr create_contract')
         contract = self._get_contract(data=payload, is_read=False)
         self._post(contract.data)
 
@@ -340,7 +314,7 @@ class UpdatePointMixin:
 
     def update(self, payload: dict):
         if self._update_contract is None:
-            raise ContractNotSet(f'Set attr update_contract')
+            raise PointError(f'Set attr update_contract')
 
         contract = self._get_contract(data=payload, is_read=False)
         self._put(contract.validated_data)
@@ -354,7 +328,7 @@ class ResponseMixin:
     @property
     def response(self) -> OrderedDict:
         if self._response_contract is None:
-            raise ContractNotSet('Response contract not set')
+            raise PointError('Response contract not set')
         if self._response is None:
             raise PointError('First create or update data')
         if self._response.status_code != status.HTTP_201_CREATED:
